gracedb-sdk Documentation
=========================

gracedb-sdk is a REST API client for the LIGO/Virgo Gravitational-Wave
Candidate Event Database (`GraceDB`_). It uses the powerful `httpx`_ package
for reliable and high-throughput HTTP connection pooling.

Quick Start
-----------

Install with pip_::

    pip install gracedb-sdk

API
---

.. automodule:: gracedb_sdk

.. _GraceDB: https://gracedb.ligo.org/
.. _httpx: https://www.python-httpx.org
.. _pip: http://pip.pypa.io
